Index: wp-includes/deprecated.php
===================================================================
--- wp-includes/deprecated.php	(revision 20037)
+++ wp-includes/deprecated.php	(working copy)
@@ -2952,4 +2952,47 @@
 	if ( is_array( $themes ) && array_key_exists( $theme, $themes ) )
 		return $themes[$theme];
 	return null;
+}
+
+/**
+ * Display information about the site.
+ *
+ * @see get_siteinfo() For possible values for the parameter.
+ * @since 0.71
+ *
+ * @param string $show What to display.
+ */
+function bloginfo( $show='' ) { 
+	_deprecated_function( __FUNCTION__, '3.4', 'siteinfo' );
+	siteinfo( $show );
+}
+
+/**
+ * Retrieve information about the site.
+ *
+ * Some show parameter values are deprecated and will be removed in future
+ * versions. These options will trigger the _deprecated_argument() function.
+ * The deprecated blog info options are listed in the function contents.
+ *
+ * The possible values for the 'show' parameter are listed below.
+ * <ol>
+ * <li><strong>url</strong> - Site URI to homepage.</li>
+ * <li><strong>wpurl</strong> - Site URI path to WordPress.</li>
+ * <li><strong>description</strong> - Secondary title</li>
+ * </ol>
+ *
+ * The feed URL options can be retrieved from 'rdf_url' (RSS 0.91),
+ * 'rss_url' (RSS 1.0), 'rss2_url' (RSS 2.0), or 'atom_url' (Atom feed). The
+ * comment feeds can be retrieved from the 'comments_atom_url' (Atom comment
+ * feed) or 'comments_rss2_url' (RSS 2.0 comment feed).
+ *
+ * @since 0.71
+ *
+ * @param string $show site info to retrieve.
+ * @param string $filter How to filter what is retrieved.
+ * @return string Mostly string values, might be empty.
+ */
+function get_bloginfo( $show = '', $filter = 'raw' ) {
+	_deprecated_function( __FUNCTION__, '3.4', 'siteinfo()' );
+	return get_siteinfo( $show, $filter );
 }
\ No newline at end of file

Index: wp-includes/general-template.php
===================================================================
--- wp-includes/general-template.php	(revision 20037)
+++ wp-includes/general-template.php	(working copy)
@@ -361,19 +361,19 @@
 }
 
 /**
- * Display information about the blog.
+ * Display information about the site.
  *
  * @see get_bloginfo() For possible values for the parameter.
  * @since 0.71
  *
  * @param string $show What to display.
  */
-function bloginfo( $show='' ) {
-	echo get_bloginfo( $show, 'display' );
+function siteinfo( $show='' ) {
+	echo get_siteinfo( $show, 'display' );
 }
 
 /**
- * Retrieve information about the blog.
+ * Retrieve information about the site.
  *
  * Some show parameter values are deprecated and will be removed in future
  * versions. These options will trigger the _deprecated_argument() function.
@@ -381,8 +381,8 @@
  *
  * The possible values for the 'show' parameter are listed below.
  * <ol>
- * <li><strong>url</strong> - Blog URI to homepage.</li>
- * <li><strong>wpurl</strong> - Blog URI path to WordPress.</li>
+ * <li><strong>url</strong> - Site URI to homepage.</li>
+ * <li><strong>wpurl</strong> - Site URI path to WordPress.</li>
  * <li><strong>description</strong> - Secondary title</li>
  * </ol>
  *
@@ -393,11 +393,11 @@
  *
  * @since 0.71
  *
- * @param string $show Blog info to retrieve.
+ * @param string $show site info to retrieve.
  * @param string $filter How to filter what is retrieved.
  * @return string Mostly string values, might be empty.
  */
-function get_bloginfo( $show = '', $filter = 'raw' ) {
+function get_siteinfo( $show = '', $filter = 'raw' ) {
 
 	switch( $show ) {
 		case 'home' : // DEPRECATED
@@ -361,19 +361,19 @@
  *
- * @see get_bloginfo() For possible values for the parameter.
+ * @see get_siteinfo() For possible values for the parameter.
  * @since 0.71
  *